import requests


def get_data(town_name):
    url = "https://rearthserver.net/map/"
    response = requests.get(url, allow_redirects=True)
    redirected_url = response.url
    endpoint_url = f"{redirected_url}tiles/_markers_/marker_world.json"
    response = requests.get(endpoint_url)
    data = response.json()
    town_data = data["sets"]["towny.markerset"]["areas"][f"{town_name}__0"]
    return town_data



import handler
from desc import Desc


class Town:
    def __init__(self, town_name):
        town_data = handler.get_data(town_name)

        self.fillcolor = town_data["fillcolor"]
        self.ytop = town_data["ytop"]
        self.color = town_data["color"]
        self.markup = town_data["markup"]
        self.x = town_data["x"]
        self.weight = town_data["weight"]
        self.z = town_data["z"]
        self.ybottom = town_data["ybottom"]
        self.label = town_data["label"]
        self.opacity = town_data["opacity"]
        self.fillopacity = town_data["fillopacity"]
        self.desc = Desc(town_data)

    def fillcolor(self):
        return self.fillcolor

    def ytop(self):
        return self.ytop

    def color(self):
        return self.ytop

    def markup(self):
        return self.markup

    def x(self):
        return self.x

    def weight(self):
        return self.weight

    def z(self):
        return self.z

    def ybottom(self):
        return self.ybottom

    def label(self):
        return self.label

    def opacity(self):
        return self.opacity

    def fillopacity(self):
        return self.fillopacity

    def desc(self):
        return self.desc



import re


class Flags:
    def __init__(self, flags_dict):
        self.has_keepup = flags_dict["has Upkeep"]
        self.pvp = flags_dict["pvp"]
        self.mobs = flags_dict["mobs"]
        self.explosion = flags_dict["explosion"]
        self.fire = flags_dict["fire"]
        self.nation = flags_dict["nation"]
        self.ruined = flags_dict["ruined"]


class Desc:
    def __init__(self, town_data):
        desc = town_data["desc"]
        flags_dict = {}
        title_match = re.search(
            r"<span style=\"font-size:120%\">(.+?)<\/span>", desc)
        if title_match:
            self.title = title_match.group(1)
        mayor_match = re.search(
            r"Mayor <span style=\"font-weight:bold\">(.+?)<\/span>", desc)
        if mayor_match:
            self.mayor = mayor_match.group(1)
        associates_match = re.search(
            r"Associates <span style=\"font-weight:bold\">(.+?)<\/span>", desc)
        if associates_match:
            self.associates = [assoc.strip()
                               for assoc in associates_match.group(1).split(",")]
        flags_match = re.search(
            r"Flags<br /><span style=\"font-weight:bold\">(.+?)<\/span>", desc)
        if flags_match:
            flags_text = flags_match.group(1)
            flags_list = flags_text.split("<br />")
            for flag in flags_list:
                key, value = flag.split(":")
                flags_dict[key.strip()] = value.strip()
            self.flags = Flags(flags_dict)
